==> shacl-1.0.1-sources.jar: org/topbraid/shacl/arq/functions/IsValidForDatatypeFunction.java <==
/*
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  See the NOTICE file distributed with this work for additional
 *  information regarding copyright ownership.
 */
package org.topbraid.shacl.arq.functions;

import org.apache.jena.datatypes.RDFDatatype;
import org.apache.jena.datatypes.TypeMapper;
import org.apache.jena.graph.Node;
import org.apache.jena.sparql.expr.ExprEvalException;
import org.apache.jena.sparql.expr.NodeValue;
import org.apache.jena.sparql.function.FunctionEnv;
import org.topbraid.spin.arq.AbstractFunction2;

/**
 * The function spif:isValidForDatatype
 * 
 * @author Holger Knublauch
 */
public class IsValidForDatatypeFunction extends AbstractFunction2 {

	@Override
	protected NodeValue exec(Node literalNode, Node datatypeNode, FunctionEnv env) {
		
		if(literalNode == null || !literalNode.isLiteral()) {
			throw new ExprEvalException();
		}
		String lex = literalNode.getLiteralLexicalForm();
		
		if(!datatypeNode.isURI()) {
			throw new ExprEvalException();
		}
		RDFDatatype datatype = TypeMapper.getInstance().getTypeByName(datatypeNode.getURI());
		
		if(datatype == null) {
			return NodeValue.TRUE;
		}
		else {
			boolean valid = datatype.isValid(lex);
			return NodeValue.makeBoolean(valid);
		}
	}
}

==> shacl-1.4.2-sources.jar: org/topbraid/shacl/arq/functions/IsValidForDatatypeFunction.java <==
/*
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  See the NOTICE file distributed with this work for additional
 *  information regarding copyright ownership.
 */
package org.topbraid.shacl.arq.functions;

import org.apache.jena.datatypes.RDFDatatype;
import org.apache.jena.datatypes.TypeMapper;
import org.apache.jena.graph.Node;
import org.apache.jena.sparql.expr.ExprEvalException;
import org.apache.jena.sparql.expr.NodeValue;
import org.apache.jena.sparql.function.FunctionEnv;
import org.topbraid.jenax.functions.AbstractFunction2;

/**
 * The function spif:isValidForDatatype
 * 
 * @author Holger Knublauch
 */
public class IsValidForDatatypeFunction extends AbstractFunction2 {

	@Override
	protected NodeValue exec(Node literalNode, Node datatypeNode, FunctionEnv env) {
		
		if(literalNode == null || !literalNode.isLiteral()) {
			throw new ExprEvalException();
		}
		String lex = literalNode.getLiteralLexicalForm();
		
		if(!datatypeNode.isURI()) {
			throw new ExprEvalException();
		}
		RDFDatatype datatype = TypeMapper.getInstance().getTypeByName(datatypeNode.getURI());
		
		if(datatype == null) {
			return NodeValue.TRUE;
		}
		else {
			boolean valid = datatype.isValid(lex);
			return NodeValue.makeBoolean(valid);
		}
	}
}
